@@ -26,21 +26,14 @@
 
 #include <libguile.h>
 
+#include <glib.h>
 #include <glib/gi18n.h>
-#include <glib/gthread.h>
 
-#include <gtk/gtkaboutdialog.h>
-#include <gtk/gtkicontheme.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtk.h>
 
-#ifdef HAVE_GNOME
-#include <libgnome/gnome-program.h>
-#include <libgnomeui/gnome-app-helper.h>
-#include <libgnomeui/gnome-client.h>
-#include <libgnomeui/gnome-help.h>
-#include <libgnomeui/gnome-ui-init.h>
-#endif /* HAVE_GNOME */
+#ifdef HAVE_CLUTTER
+#include <clutter/clutter.h>
+#endif
 
 #ifdef HAVE_HILDON
 #include <libosso.h>
@@ -69,35 +62,39 @@
 
 #include <libgames-support/games-files.h>
 #include <libgames-support/games-stock.h>
+#include <libgames-support/games-runtime.h>
 #include <libgames-support/games-sound.h>
 
+#ifdef WITH_SMCLIENT
+#include <libgames-support/eggsmclient.h>
+#endif /* WITH_SMCLIENT */
+
 #include "conf.h"
 #include "game.h"
 #include "util.h"
 #include "window.h"
 
+#ifdef HAVE_CLUTTER
+#include "clutter-embed.h"
+#endif
+
 typedef struct {
   AisleriotWindow *window;
   char *variation;
   guint seed;
   gboolean freecell;
-#ifdef HAVE_GNOME
-  GnomeProgram *program;
-#endif
 #ifdef HAVE_HILDON
   osso_context_t *osso_context;
   HildonProgram *program;
-#endif
+#endif /* HAVE_HILDON */
 } AppData;
 
-#ifndef HAVE_GNOME
-
 static void
 about_url_hook (GtkAboutDialog *about,
                 const char *link,
                 gpointer user_data)
 {
-#ifdef HAVE_MAEMO
+#if defined(HAVE_MAEMO)
   AppData *data = (AppData *) user_data;
 
   osso_rpc_run_with_defaults (data->osso_context,
@@ -113,18 +110,10 @@ about_url_hook (GtkAboutDialog *about,
 
   GdkScreen *screen;
   GError *error = NULL;
-  char *argv[3] = { (char *) "gnome-open", (char *) link, NULL };
 
   screen = gtk_widget_get_screen (GTK_WIDGET (about));
 
-  if (!gdk_spawn_on_screen (screen,
-                            NULL /* working directory */,
-                            argv,
-                            NULL /* environment */,
-                            G_SPAWN_SEARCH_PATH,
-                            NULL, NULL,
-                            NULL,
-                            &error)) {
+  if (!gtk_show_uri (screen, link, gtk_get_current_event_time (), &error)) {
     GtkWidget *dialog;
 
     dialog = gtk_message_dialog_new (GTK_WINDOW (about),
@@ -132,7 +121,7 @@ about_url_hook (GtkAboutDialog *about,
                                      GTK_DIALOG_MODAL,
                                      GTK_MESSAGE_ERROR,
                                      GTK_BUTTONS_CLOSE,
-                                     _("Could not show link"));
+                                     "%s", _("Could not show link"));
     gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
                                               "%s", error->message);
     g_error_free (error);
@@ -148,7 +137,20 @@ about_url_hook (GtkAboutDialog *about,
 #endif /* HAVE_MAEMO */
 }
 
-#endif /* !HAVE_GNOME */
+static void
+about_email_hook (GtkAboutDialog *about,
+                  const char *email_address,
+                  gpointer user_data)
+{
+  char *escaped, *uri;
+
+  escaped = g_uri_escape_string (email_address, NULL, FALSE);
+  uri = g_strdup_printf ("mailto:%s", escaped);
+  g_free (escaped);
+
+  about_url_hook (about, uri, user_data);
+  g_free (uri);
+}
 
 static char *
 variation_to_game_file (const char *variation)
@@ -173,16 +175,12 @@ variation_to_game_file (const char *variation)
   return s;
 }
 
-#ifdef HAVE_GNOME
+#ifdef WITH_SMCLIENT
 
-static gboolean
-save_yourself_cb (GnomeClient *client,
-                  int phase,
-                  GnomeSaveStyle save_style,
-                  gboolean shutdown,
-                  GnomeInteractStyle interact_style,
-                  gboolean fast,
-                  AppData *data)
+static void
+save_state_cb (EggSMClient *client,
+               GKeyFile *key_file,
+               AppData *data)
 {
   AisleriotGame *game;
   char *argv[5];
@@ -209,22 +207,20 @@ save_yourself_cb (GnomeClient *client,
 
   /* FIXMEchpe: save game state too? */
 
-  gnome_client_set_restart_command (client, argc, argv);
+  egg_sm_client_set_restart_command (client, argc, (const char **) argv);
 
   g_free (seed);
-
-  return TRUE;
 }
 
 static void
-die_cb (GnomeClient *client,
-        AppData *data)
+quit_cb (EggSMClient *client,
+         AppData *data)
 {
   /* This will cause gtk_main_quit */
   gtk_widget_destroy (GTK_WIDGET (data->window));
 }
 
-#endif /* HAVE_GNOME */
+#endif /* WITH_SMCLIENT */
 
 static char *
 game_file_to_help_section (const char *game_file)
@@ -331,7 +327,7 @@ help_hook (GtkWindow *parent,
   g_free (help_url);
 }
 
-#else /* !HAVE_MAEMO */
+#else /* !HAVE_HILDON */
 
 static void
 help_hook (GtkWindow *parent,
@@ -339,12 +335,9 @@ help_hook (GtkWindow *parent,
            gpointer user_data)
 {
   GdkScreen *screen;
-  char *help_section = NULL;
   GError *error = NULL;
-#ifndef HAVE_GNOME
-  char *help_url = NULL;
-  char *argv[3];
-#endif /* !HAVE_GNOME */
+  char *help_section = NULL;
+  char *help_uri;
 
   screen = gtk_widget_get_screen (GTK_WIDGET (parent));
 
@@ -352,30 +345,17 @@ help_hook (GtkWindow *parent,
     help_section = game_file_to_help_section (game_file);
   }
 
-#ifdef HAVE_GNOME
-  if (!gnome_help_display_on_screen ("aisleriot.xml", help_section, screen, &error)) {
-#else
-
   if (help_section != NULL) {
-    /* FIXMEchpe: URL-escape? */
-    help_url = g_strdup_printf ("ghelp:aisleriot?%s", help_section);
+    char *escaped;
+
+    escaped = g_uri_escape_string  (help_section, NULL, TRUE);
+    help_uri = g_strdup_printf ("ghelp:aisleriot?%s", escaped);
+    g_free (escaped);
   } else {
-    help_url = g_strdup ("ghelp:aisleriot");
+    help_uri = g_strdup ("ghelp:aisleriot");
   }
 
-  argv[0] = "gnome-open";
-  argv[1] = help_url;
-  argv[2] = NULL;
-
-  if (!gdk_spawn_on_screen (screen,
-                            NULL /* working directory */,
-                            argv,
-                            NULL /* environment */,
-                            G_SPAWN_SEARCH_PATH,
-                            NULL, NULL,
-                            NULL,
-                            &error)) {
-#endif /* !HAVE_GNOME */
+  if (!gtk_show_uri (screen, help_uri, gtk_get_current_event_time (), &error)) {
     GtkWidget *dialog;
     char *primary;
 
@@ -383,7 +363,7 @@ help_hook (GtkWindow *parent,
       char *game_name;
  
       game_name = aisleriot_util_get_display_filename (game_file);
-      primary = g_strdup_printf (_("Could not show help for \"%s\""), game_name);
+      primary = g_strdup_printf (_("Could not show help for “%s”"), game_name);
       g_free (game_name);
     } else {
       primary = g_strdup (_("Could not show Aisleriot help"));
@@ -416,9 +396,7 @@ help_hook (GtkWindow *parent,
   }
 
   g_free (help_section);
-#ifndef HAVE_GNOME
-  g_free (help_url);
-#endif /* !HAVE_GNOME */
+  g_free (help_uri);
 }
 
 #endif /* HAVE_HILDON */
@@ -447,7 +425,7 @@ osso_hw_event_cb (osso_hw_state_t *state,
   } else if (state->system_inactivity_ind) {
     g_print ("System inactive\n");
   }
-#endif
+#endif /* GNOME_ENABLE_DEBUG */
 }
 
 static int
@@ -461,7 +439,7 @@ osso_rpc_cb (const char *interface,
 
 #if GNOME_ENABLE_DEBUG
   g_print ("OSSO RPC iface %s method %s\n", interface, method);
-#endif
+#endif /* GNOME_ENABLE_DEBUG */
 
   if (strcmp (method, "top_application") == 0) {
     gtk_window_present (GTK_WINDOW (data->window));
@@ -510,13 +488,11 @@ main_prog (void *closure, int argc, char *argv[])
 {
   AppData data;
   GOptionContext *option_context;
-  GtkIconTheme *sol_icon_theme;
-#ifdef HAVE_GNOME
-  GnomeClient *master_client;
-#else
   GError *error = NULL;
   gboolean retval;
-#endif
+#ifdef WITH_SMCLIENT
+  EggSMClient *sm_client;
+#endif /* WITH_SMCLIENT */
 #ifdef HAVE_MAEMO
   osso_hw_state_t hw_events = {
     TRUE /* shutdown */,
@@ -528,7 +504,7 @@ main_prog (void *closure, int argc, char *argv[])
      * when not interested in this signal? The docs don't tell.
      */
   };
-#endif
+#endif /* HAVE_MAEMO */
 
   memset (&data, 0, sizeof (AppData));
 
@@ -559,31 +535,37 @@ main_prog (void *closure, int argc, char *argv[])
   option_context = g_option_context_new (NULL);
 #if GLIB_CHECK_VERSION (2, 12, 0)
   g_option_context_set_translation_domain (option_context, GETTEXT_PACKAGE);
-#endif
+#endif /* GLIB 2.12.0 */
 
   add_main_options (option_context, &data);
 
   games_sound_enable (FALSE);
   games_sound_add_option_group (option_context);
 
-#ifdef HAVE_GNOME
-  data.program = gnome_program_init ("aisleriot", VERSION,
-                                     LIBGNOMEUI_MODULE,
-                                     argc, argv,
-                                     GNOME_PARAM_GOPTION_CONTEXT, option_context,
-                                     GNOME_PARAM_APP_DATADIR, DATADIR,
-                                     NULL);
-#else /* !HAVE_GNOME */
   g_option_context_add_group (option_context, gtk_get_option_group (TRUE));
+#ifdef WITH_SMCLIENT
+  g_option_context_add_group (option_context, egg_sm_client_get_option_group ());
+#endif /* WITH_SMCLIENT */
+#ifdef HAVE_CLUTTER
+  g_option_context_add_group (option_context, clutter_get_option_group_without_init ());
+#endif
 
   retval = g_option_context_parse (option_context, &argc, &argv, &error);
   g_option_context_free (option_context);
 
   if (!retval) {
-    g_print ("%s\n", error->message);
+    g_printerr ("%s\n", error->message);
+    g_error_free (error);
     goto cleanup;
   }
-#endif /* HAVE_GNOME */
+
+#ifdef HAVE_CLUTTER
+  if (aisleriot_clutter_init_with_args (NULL, NULL, NULL, NULL, NULL, &error) != CLUTTER_INIT_SUCCESS) {
+    g_printerr ("Failed to initialise clutter: %s\n", error->message);
+    g_error_free (error);
+    goto cleanup;
+  }
+#endif
 
 #ifdef HAVE_MAEMO
   data.program = HILDON_PROGRAM (hildon_program_get_instance ());
@@ -619,27 +601,22 @@ main_prog (void *closure, int argc, char *argv[])
 
   aisleriot_util_set_help_func (help_hook, &data);
 
-#if (!defined (HAVE_GNOME) || defined (G_OS_WIN32))
   gtk_about_dialog_set_url_hook (about_url_hook, &data, NULL);
-#endif
+  gtk_about_dialog_set_email_hook (about_email_hook, &data, NULL);
 
   data.window = AISLERIOT_WINDOW (aisleriot_window_new ());
   g_signal_connect (data.window, "destroy",
 		    G_CALLBACK (gtk_main_quit), NULL);
 
-  sol_icon_theme = gtk_icon_theme_get_for_screen (gtk_widget_get_screen (GTK_WIDGET (data.window)));
-  gtk_icon_theme_append_search_path (sol_icon_theme, games_path_runtime_fix (ICONDIR));
-
   gtk_window_set_default_icon_name (data.freecell ? "gnome-freecell" : "gnome-aisleriot");
 
-
-#ifdef HAVE_GNOME
-  master_client = gnome_master_client ();
-  g_signal_connect (master_client, "save-yourself",
-		    G_CALLBACK (save_yourself_cb), &data);
-  g_signal_connect (master_client, "die",
-                    G_CALLBACK (die_cb), &data);
-#endif /* HAVE_GNOME */
+#ifdef WITH_SMCLIENT
+  sm_client = egg_sm_client_get ();
+  g_signal_connect (sm_client, "save-state",
+		    G_CALLBACK (save_state_cb), &data);
+  g_signal_connect (sm_client, "quit",
+                    G_CALLBACK (quit_cb), &data);
+#endif /* WITH_SMCLIENT */
 
 #ifdef HAVE_HILDON
   hildon_program_add_window (data.program, HILDON_WINDOW (data.window));
@@ -664,7 +641,7 @@ main_prog (void *closure, int argc, char *argv[])
                 "hildon-keyboard-shortcuts", FALSE,
 #endif /* GTK 2.10.0 */
                 NULL);
-#endif /* HAVE_MAEMO */
+#endif /* HAVE_HILDON */
 
   if (data.freecell) {
     aisleriot_window_set_freecell_mode (data.window);
@@ -679,15 +656,13 @@ main_prog (void *closure, int argc, char *argv[])
 
   aisleriot_conf_shutdown ();
 
-#ifndef HAVE_GNOME
-cleanup:
-#endif
-
+  cleanup:
   g_free (data.variation);
 
-#ifdef HAVE_GNOME
-  g_object_unref (data.program);
-#endif /* HAVE_GNOME */
+#ifdef WITH_SMCLIENT
+  g_signal_handlers_disconnect_matched (sm_client, G_SIGNAL_MATCH_DATA,
+                                        0, 0, NULL, NULL, &data);
+#endif /* WITH_SMCLIENT */
 
 #ifdef HAVE_MAEMO
   if (data.program != NULL) {
@@ -697,13 +672,13 @@ cleanup:
     osso_deinitialize (data.osso_context);
   }
 #endif /* HAVE_MAEMO */
+
+  games_runtime_shutdown ();
 }
 
 int
 main (int argc, char *argv[])
 {
-  char *localedir;
-
   setlocale (LC_ALL, "");
 
 #if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS) || defined(HAVE_GSTREAMER)
@@ -713,13 +688,14 @@ main (int argc, char *argv[])
   g_thread_init (NULL);
 #endif
 
-  localedir = games_path_runtime_fix (GNOMELOCALEDIR);
-  bindtextdomain (GETTEXT_PACKAGE, localedir);
+  if (!games_runtime_init ("aisleriot"))
+    return 1;
+
+  bindtextdomain (GETTEXT_PACKAGE, games_runtime_get_directory (GAMES_RUNTIME_LOCALE_DIRECTORY));
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
-  g_free (localedir);
 
-  scm_boot_guile (argc, argv, main_prog, NULL);
+  scm_boot_guile (argc, argv, main_prog, NULL); /* no return */
 
   return 0;
 }
