@@ -31,20 +31,24 @@
 
 #include <glib.h>
 #include <glib/gi18n.h>
+#include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk/gdkkeysyms.h>
-#include <games-scores.h>
-#include <games-scores-dialog.h>
-#include <games-frame.h>
-#include <games-files.h>
-#include <games-gridframe.h>
-#include <games-preimage.h>
-#include <games-stock.h>
-#include <games-conf.h>
 
-#ifdef HAVE_GNOME
-#include <gnome.h>
-#endif
+#include <libgames-support/games-conf.h>
+#include <libgames-support/games-files.h>
+#include <libgames-support/games-frame.h>
+#include <libgames-support/games-gridframe.h>
+#include <libgames-support/games-help.h>
+#include <libgames-support/games-preimage.h>
+#include <libgames-support/games-runtime.h>
+#include <libgames-support/games-scores.h>
+#include <libgames-support/games-scores-dialog.h>
+#include <libgames-support/games-stock.h>
+
+#ifdef WITH_SMCLIENT
+#include <libgames-support/eggsmclient.h>
+#endif /* WITH_SMCLIENT */
 
 #include "glines.h"
 
@@ -191,10 +195,10 @@ show_image_warning (gchar * message)
 				   GTK_DIALOG_MODAL,
 				   GTK_MESSAGE_WARNING,
 				   GTK_BUTTONS_CLOSE,
-				   _("Could not load theme"));
+				   "%s",_("Could not load theme"));
 
   gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-					    message);
+					    "%s", message);
 
   button = gtk_dialog_add_button (GTK_DIALOG (dialog),
 				  _("Preferences"), GTK_RESPONSE_ACCEPT);
@@ -213,15 +217,17 @@ load_image (gchar * fname)
 {
   GamesPreimage *preimage;
   gchar *path;
+  const char *dirname;
   GError *error = NULL;
 
-  path = g_build_filename (PIXMAPDIR, fname, NULL);
+  dirname = games_runtime_get_directory (GAMES_RUNTIME_GAME_PIXMAP_DIRECTORY);
+  path = g_build_filename (dirname, fname, NULL);
   if (!g_file_test (path, G_FILE_TEST_EXISTS)) {
     warning_message = g_strdup_printf (_("Unable to locate file:\n%s\n\n"
 					 "The default theme will be loaded instead."),
 				       fname);
 
-    path = g_build_filename (PIXMAPDIR, "balls.svg", NULL);
+    path = g_build_filename (dirname, "balls.svg", NULL);
     if (!g_file_test (path, G_FILE_TEST_EXISTS)) {
       g_free (warning_message);
       warning_message = g_strdup_printf (_("Unable to locate file:\n%s\n\n"
@@ -1214,7 +1220,7 @@ game_about_callback (GtkAction * action, gpointer * data)
 			 "version", VERSION,
 			 "comments", _("GNOME port of the once-popular Color Lines game.\n\nFive or More is a part of GNOME Games."),
 			 "copyright",
-			 "Copyright \xc2\xa9 1997-2007 Free Software Foundation, Inc.",
+			 "Copyright \xc2\xa9 1997-2008 Free Software Foundation, Inc.",
 			 "license", license,
                          "authors", authors,
 			 "documenters", documenters,
@@ -1373,10 +1379,13 @@ set_selection (GtkWidget * widget, char *data)
 static GtkWidget *
 fill_menu (void)
 {
+  char *pixmap_dir;
+
   if (theme_file_list)
     g_object_unref (theme_file_list);
 
-  theme_file_list = games_file_list_new_images (PIXMAPDIR, NULL);
+  pixmap_dir = games_runtime_get_directory (GAMES_RUNTIME_GAME_PIXMAP_DIRECTORY);
+  theme_file_list = games_file_list_new_images (pixmap_dir, NULL);
   games_file_list_transform_basename (theme_file_list);
 
   return games_file_list_create_widget (theme_file_list, ball_filename,
@@ -1560,11 +1569,7 @@ game_quit_callback (GtkAction * action, gpointer data)
 static void
 game_help_callback (GtkAction * action, gpointer data)
 {
-#ifdef HAVE_GNOME
-  gnome_help_display ("glines.xml", NULL, NULL);
-#else
-#warning need to port help to gtk-only!
-#endif /* HAVE_GNOME */
+  games_help_display (app, "glines", NULL);
 }
 
 static int
@@ -1600,17 +1605,15 @@ configure_event_callback (GtkWidget * widget, GdkEventConfigure * event)
   return TRUE;
 }
 
-#ifdef HAVE_GNOME
-
+#ifdef WITH_SMCLIENT
 static int
-save_state (GnomeClient * client,
-	    gint phase,
-	    GnomeSaveStyle save_style,
-	    gint shutdown,
-	    GnomeInteractStyle interact_style,
-	    gint fast, gpointer client_data)
+save_state_cb (EggSMClient *client,
+	    GKeyFile* keyfile,
+	    gpointer client_data)
 {
   gchar *buf;
+  int argc = 0;
+  char *argv[1];
   int i;
 
   games_conf_set_integer (KEY_SAVED_GROUP, KEY_SAVED_SCORE, score);
@@ -1630,18 +1633,23 @@ save_state (GnomeClient * client,
   games_conf_set_string (KEY_SAVED_GROUP, KEY_SAVED_PREVIEW, buf);
   g_free (buf);
 
+  argv[argc++] = g_get_prgname ();
+
+  egg_sm_client_set_restart_command (client, argc, (const char **) argv);
+
   return TRUE;
 }
 
 static gint
-client_die (GnomeClient * client, gpointer client_data)
+quit_cb (EggSMClient *client,
+         gpointer client_data)
 {
   gtk_main_quit ();
 
   return FALSE;
 }
 
-#endif /* HAVE_GNOME */
+#endif /* WITH_SMCLIENT */
 
 static void
 load_properties (void)
@@ -1761,16 +1769,6 @@ create_menus (GtkUIManager * ui_manager)
   menubar = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
 }
 
-#ifdef HAVE_GNOME
-#ifndef GNOME_CLIENT_RESTARTED
-#define GNOME_CLIENT_RESTARTED(client) \
-(GNOME_CLIENT_CONNECTED (client) && \
- (gnome_client_get_previous_id (client) != NULL) && \
- (strcmp (gnome_client_get_id (client), \
-  gnome_client_get_previous_id (client)) == 0))
-#endif /* GNOME_CLIENT_RESTARTED */
-#endif /* HAVE_GNOME */
-
 static void
 init_config (void)
 {
@@ -1795,13 +1793,11 @@ main (int argc, char *argv[])
   GtkWidget *preview_hbox;
   GtkUIManager *ui_manager;
   guint i;
-#ifdef HAVE_GNOME
-  GnomeClient *client;
-  GnomeProgram *program;
-#else
   gboolean retval;
   GError *error = NULL;
-#endif
+#ifdef WITH_SMCLIENT
+  EggSMClient *sm_client;
+#endif /* WITH_SMCLIENT */
 
 #if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS)
   /* If we're going to use gnome-vfs, we need to init threads before
@@ -1810,11 +1806,14 @@ main (int argc, char *argv[])
   g_thread_init (NULL);
 #endif
 
+  if (!games_runtime_init ("glines"))
+    return 1;
+
   setgid_io_init ();
 
   rgen = g_rand_new ();
 
-  bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+  bindtextdomain (GETTEXT_PACKAGE, games_runtime_get_directory (GAMES_RUNTIME_LOCALE_DIRECTORY));
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
@@ -1823,15 +1822,10 @@ main (int argc, char *argv[])
   g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
 #endif
 
-#ifdef HAVE_GNOME
-  program = gnome_program_init ("glines", VERSION,
-				LIBGNOMEUI_MODULE,
-				argc, argv,
-				GNOME_PARAM_GOPTION_CONTEXT, context,
-				GNOME_PARAM_APP_DATADIR, DATADIR, /* FIXMEchpe: this ought to use SHAREDIR !! */
-                                NULL);
-#else
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
+#ifdef WITH_SMCLIENT
+  g_option_context_add_group (context, egg_sm_client_get_option_group ());
+#endif /* WITH_SMCLIENT */
 
   retval = g_option_context_parse (context, &argc, &argv, &error);
   g_option_context_free (context);
@@ -1840,7 +1834,8 @@ main (int argc, char *argv[])
     g_error_free (error);
     exit (1);
   }
-#endif /* HAVE_GNOME */
+
+  g_set_application_name (_("Five or More"));
 
   games_conf_initialise ("GLines");
 
@@ -1852,20 +1847,19 @@ main (int argc, char *argv[])
 
   gtk_window_set_default_icon_name ("gnome-glines");
 
-#ifdef HAVE_GNOME
-  client = gnome_master_client ();
-  g_signal_connect (client, "save-yourself",
-		    G_CALLBACK (save_state), argv[0]);
-  g_signal_connect (client, "die",
-                    G_CALLBACK (client_die), NULL);
-
-  if (GNOME_CLIENT_RESTARTED (client))
+#ifdef WITH_SMCLIENT
+  sm_client = egg_sm_client_get ();
+  g_signal_connect (sm_client, "save-state",
+		    G_CALLBACK (save_state_cb), NULL);
+  g_signal_connect (sm_client, "quit",
+                    G_CALLBACK (quit_cb), NULL);
+  if (egg_sm_client_is_resumed(sm_client))
     restart ();
   else
     reset_game ();
 #else
   reset_game ();
-#endif /* HAVE_GNOME */
+#endif /* WITH_SMCLIENT */
 
   app = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
@@ -1975,9 +1969,12 @@ main (int argc, char *argv[])
 
   games_conf_shutdown ();
 
-#ifdef HAVE_GNOME
-  g_object_unref (program);
-#endif /* HAVE_GNOME */
+#ifdef WITH_SMCLIENT
+  g_signal_handlers_disconnect_matched (sm_client, G_SIGNAL_MATCH_DATA,
+                                        0, 0, NULL, NULL, NULL);
+#endif /* WITH_SMCLIENT */
+
+  games_runtime_shutdown ();
 
   return 0;
 }
