@@ -20,15 +20,25 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+
 #include <sys/time.h>
 #include <string.h>
-#include <games-stock.h>
-#include <games-scores.h>
-#include <games-scores-dialog.h>
-#include <games-sound.h>
-#include <games-gridframe.h>
-#include <games-conf.h>
+#include <stdlib.h>
+
+#include <glib/gi18n.h>
+#include <glib.h>
+
+#include <libgames-support/games-conf.h>
+#include <libgames-support/games-gridframe.h>
+#include <libgames-support/games-runtime.h>
+#include <libgames-support/games-scores.h>
+#include <libgames-support/games-scores-dialog.h>
+#include <libgames-support/games-sound.h>
+#include <libgames-support/games-stock.h>
+
+#ifdef WITH_SMCLIENT
+#include <libgames-support/eggsmclient.h>
+#endif /* WITH_SMCLIENT */
 
 #include "gbdefs.h"
 #include "statusbar.h"
@@ -89,7 +99,7 @@ static const GamesScoresCategory scorecats[] = {
   {"classic_robots-super-safe", N_("Classic robots with super-safe moves")},
   {"nightmare", N_("Nightmare")},
   {"nightmare-safe", N_("Nightmare with safe moves")},
-  {"nightmare.-super-safe", N_("Nightmare with super-safe moves")},
+  {"nightmare-super-safe", N_("Nightmare with super-safe moves")},
   {"robots2", N_("Robots2")},
   {"robots2-safe", N_("Robots2 with safe moves")},
   {"robots2-super-safe", N_("Robots2 with super-safe moves")},
@@ -114,8 +124,10 @@ static const GamesScoresDescription scoredesc = { scorecats,
 /**********************************************************************/
 /* Function Prototypes                                                */
 /**********************************************************************/
-static gint save_state (GnomeClient *, gint, GnomeRestartStyle, gint,
-			GnomeInteractStyle, gint, gpointer);
+#ifdef WITH_SMCLIENT
+static gint save_state_cb (EggSMClient *, GKeyFile *, gpointer);
+static gint quit_sm_cb (EggSMClient *, gpointer);
+#endif /* WITH_SMCLIENT */
 /**********************************************************************/
 
 
@@ -123,6 +135,7 @@ static gint save_state (GnomeClient *, gint, GnomeRestartStyle, gint,
 /* Function Definitions                                               */
 /**********************************************************************/
 
+#ifdef WITH_SMCLIENT
 /**
  * save_state
  * @client: gnome client
@@ -140,12 +153,9 @@ static gint save_state (GnomeClient *, gint, GnomeRestartStyle, gint,
  * TRUE on success, FALSE otherwise
  **/
 static gint
-save_state (GnomeClient * client,
-	    gint phase,
-	    GnomeRestartStyle save_style,
-	    gint shutdown,
-	    GnomeInteractStyle interact_style,
-	    gint fast, gpointer client_data)
+save_state_cb (EggSMClient *client,
+	    GKeyFile* keyfile,
+	    gpointer client_data)
 {
   char *argv[20];
   int i;
@@ -160,9 +170,7 @@ save_state (GnomeClient * client,
   argv[i++] = "-y";
   argv[i++] = g_strdup_printf ("%d", ypos);
 
-  gnome_client_set_restart_command (client, i, argv);
-  /* i.e. clone_command = restart_command - '--sm-client-id' */
-  gnome_client_set_clone_command (client, 0, NULL);
+  egg_sm_client_set_restart_command (client, i, (const char **) argv);
 
   g_free (argv[2]);
   g_free (argv[4]);
@@ -170,6 +178,15 @@ save_state (GnomeClient * client,
   return TRUE;
 }
 
+static gint
+quit_sm_cb (EggSMClient *client,
+         gpointer client_data)
+{
+  quit_game();
+
+  return FALSE;
+}
+#endif /* WITH_SMCLIENT */
 
 /**
  * main
@@ -188,34 +205,51 @@ main (int argc, char *argv[])
   GtkWidget *errordialog;
   GtkWidget *vbox, *menubar, *toolbar, *statusbar, *gridframe;
   GtkUIManager *ui_manager;
-  GnomeClient *client;
-  GnomeProgram *program;
-  GOptionContext *option_context;
+  GOptionContext *context;
   struct timeval tv;
   gint i;
+  gboolean retval;
+  GError *error = NULL;
+#ifdef WITH_SMCLIENT
+  EggSMClient *sm_client;
+#endif /* WITH_SMCLIENT */
 
-  bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+  g_thread_init (NULL);
+
+  if (!games_runtime_init ("gnobots2"))
+    return 1;
+
+  bindtextdomain (GETTEXT_PACKAGE, games_runtime_get_directory (GAMES_RUNTIME_LOCALE_DIRECTORY));
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
  
-  g_thread_init (NULL);
-
   gettimeofday (&tv, NULL);
   srand (tv.tv_usec);
 
   setgid_io_init ();
 
-  option_context = g_option_context_new (NULL);
-  g_option_context_add_main_entries (option_context, options,
-				     GETTEXT_PACKAGE);
-  games_sound_add_option_group (option_context);
+  context = g_option_context_new (NULL);
+#if GLIB_CHECK_VERSION (2, 12, 0)
+  g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
+#endif
 
-  program = gnome_program_init (GAME_NAME, VERSION,
-				LIBGNOMEUI_MODULE,
-				argc, argv,
-				GNOME_PARAM_GOPTION_CONTEXT, option_context,
-				GNOME_PARAM_APP_DATADIR, DATADIR,
-				GNOME_PARAM_NONE);
+  g_option_context_add_group (context, gtk_get_option_group (TRUE));
+#ifdef WITH_SMCLIENT
+  g_option_context_add_group (context, egg_sm_client_get_option_group ());
+#endif /* WITH_SMCLIENT */
+
+  g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
+  games_sound_add_option_group (context);
+
+  retval = g_option_context_parse (context, &argc, &argv, &error);
+  g_option_context_free (context);
+  if (!retval) {
+    g_print ("%s", error->message);
+    g_error_free (error);
+    exit (1);
+  }
+
+  g_set_application_name (_("Robots"));
 
   highscores = games_scores_new (&scoredesc);
 
@@ -223,14 +257,16 @@ main (int argc, char *argv[])
 
   gtk_window_set_default_icon_name ("gnome-robots");
 
-  client = gnome_master_client ();
+#ifdef WITH_SMCLIENT
+  sm_client = egg_sm_client_get ();
+  g_signal_connect (sm_client, "save-state",
+		    G_CALLBACK (save_state_cb), NULL);
+  g_signal_connect (sm_client, "quit",
+                    G_CALLBACK (quit_sm_cb), NULL);
+#endif /* WITH_SMCLIENT */
 
-  g_signal_connect (G_OBJECT (client), "save_yourself",
-		    G_CALLBACK (save_state), argv[0]);
-  g_signal_connect (G_OBJECT (client), "die",
-		    G_CALLBACK (quit_game), argv[0]);
-
-  app = gnome_app_new (GAME_NAME, _("Robots"));
+  app = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+  gtk_window_set_title (GTK_WINDOW (app), _("Robots"));
 
   gtk_window_set_default_size (GTK_WINDOW (app), DEFAULT_WIDTH, DEFAULT_HEIGHT);
   games_conf_add_window (GTK_WINDOW (app), KEY_GEOMETRY_GROUP);
@@ -274,7 +310,7 @@ main (int argc, char *argv[])
   gtk_box_pack_start (GTK_BOX (vbox), gridframe, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), statusbar, FALSE, FALSE, 0);
 
-  gnome_app_set_contents (GNOME_APP (app), vbox);
+  gtk_container_add (GTK_CONTAINER (app), vbox);
 
   gtk_widget_set_size_request (GTK_WIDGET (game_area),
 			       MINIMUM_TILE_WIDTH * GAME_WIDTH,
@@ -349,7 +385,7 @@ main (int argc, char *argv[])
 
   games_conf_shutdown ();
 
-  g_object_unref (program);
+  games_runtime_shutdown ();
 
   return 0;
 }
