@@ -20,11 +20,14 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
-#include <games-preimage.h>
 #include <games-find-file.h>
+#include <games-preimage.h>
+#include <games-runtime.h>
 #include <games-scores.h>
 #include <games-scores-dialog.h>
 
@@ -172,9 +175,9 @@ static gboolean
 load_bubble_graphics (void)
 {
   gchar *buffer = NULL;
-  gchar *dname =
-    gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP,
-			       GAME_NAME, FALSE, NULL);
+  const char *dname;
+
+  dname = games_runtime_get_directory (GAMES_RUNTIME_GAME_PIXMAP_DIRECTORY);
 
   buffer = g_build_filename (dname, "yahoo.png", NULL);
   if (!load_bubble_graphic (buffer, &yahoo_pixbuf))
@@ -206,18 +209,20 @@ gboolean
 load_game_graphics (void)
 {
   gchar *filename;
+  const char *pixmapdir;
 
   if (theme_preimage != NULL) {
     free_game_graphics ();
   }
 
-  filename = games_find_similar_file (properties_theme_name (), PIXMAPDIR);
+  pixmapdir = games_runtime_get_directory (GAMES_RUNTIME_GAME_PIXMAP_DIRECTORY);
+  filename = games_find_similar_file (properties_theme_name (), pixmapdir);
 
   theme_preimage = games_preimage_new_from_file (filename, NULL);
   g_free (filename);
 
   if (theme_preimage == NULL) {
-    filename = games_find_similar_file ("robots", PIXMAPDIR);
+    filename = games_find_similar_file ("robots", pixmapdir);
     theme_preimage = games_preimage_new_from_file (filename, NULL);
     g_free (filename);
   }
@@ -446,11 +451,35 @@ clear_game_area (void)
 static void
 clear_bubble_area (void)
 {
+  int t0i, t0j; /* (i,j) coordinates of bubble's top/left tile */
+  int ntiles_hor, ntiles_ver; /* number of tiles hotizontal/vertically affected */
+  int delta; /* pixels from tile's left/top border to bubble's left/top border */
+  int i, j;
+
   if (game_area == NULL)
     return;
 
-  gdk_window_clear_area (game_area->window, bubble_xpos, bubble_ypos,
-			 BUBBLE_WIDTH, BUBBLE_HEIGHT);
+  t0i = bubble_xpos / tile_width;
+  t0j = bubble_ypos / tile_height;
+  ntiles_hor = (BUBBLE_WIDTH + tile_width - 1) / tile_width; /* first shot at number of tiles affected */
+  delta = bubble_xpos % tile_width;
+  if (delta > 0) { /* buble does not start at a tile's left boundary */
+    if ((BUBBLE_WIDTH + delta) > ntiles_hor * tile_width) { /* catches an extra tile */
+      ntiles_hor++;
+    }
+  }
+  ntiles_ver = (BUBBLE_HEIGHT + tile_height - 1) / tile_height;
+  delta = bubble_ypos % tile_height;
+  if (delta > 0) { /* buble does not start at a tile's top boundary */
+    if ((BUBBLE_HEIGHT + delta) > ntiles_ver * tile_height) { /* catches an extra tile */
+      ntiles_ver++;
+    }
+  }
+  for (i = t0i; i < t0i + ntiles_hor; ++i) {
+    for (j = t0j; j < t0j + ntiles_ver; ++j) {
+      draw_tile_pixmap (-1, i, j, game_area);
+    }
+  }
 }
 
 
