@@ -20,11 +20,16 @@
  */
 
 #include <config.h>
-#include <gnome.h>
+
 #include <string.h>
-#include <games-stock.h>
-#include <games-scores.h>
-#include <games-scores-dialog.h>
+
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+
+#include <libgames-support/games-help.h>
+#include <libgames-support/games-stock.h>
+#include <libgames-support/games-scores.h>
+#include <libgames-support/games-scores-dialog.h>
 
 #include "gbdefs.h"
 #include "menu.h"
@@ -233,7 +238,7 @@ quit_cb (GtkAction * action, gpointer data)
 static void
 help_cb (GtkAction * action, gpointer data)
 {
-  gnome_help_display ("gnobots2.xml", NULL, NULL);
+  games_help_display (app, "gnobots2", NULL);
 }
 
 
@@ -413,5 +418,5 @@ connect_toolbar_toggle (GtkWidget * toolbar)
   gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (toolbar_toggle_action),
 				properties_show_toolbar ());
 
-  toggle_toolbar_cb (GTK_TOGGLE_ACTION (toolbar_toggle_action), toolbar);
+  toggle_toolbar_cb (GTK_ACTION (toolbar_toggle_action), toolbar);
 }
