@@ -25,19 +25,21 @@
 #include <stdlib.h>
 
 #include <glib/gi18n.h>
-#include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtk.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 
-#include <games-preimage.h>
-#include <games-gridframe.h>
-#include <games-stock.h>
-#include <games-scores.h>
-#include <games-scores-dialog.h>
-#include <games-conf.h>
+#include <libgames-support/games-conf.h>
+#include <libgames-support/games-gridframe.h>
+#include <libgames-support/games-help.h>
+#include <libgames-support/games-preimage.h>
+#include <libgames-support/games-runtime.h>
+#include <libgames-support/games-scores.h>
+#include <libgames-support/games-scores-dialog.h>
+#include <libgames-support/games-stock.h>
 
-#ifdef HAVE_GNOME
-#include <gnome.h>
-#endif
+#ifdef WITH_SMCLIENT
+#include <libgames-support/eggsmclient.h>
+#endif /* WITH_SMCLIENT */
 
 #include "pieces.h"
 
@@ -125,15 +127,6 @@ static const GamesScoresCategory scorecats[] = { {"1", N_("Only 18 steps")},
 {"26", N_("American Pie")},
 {"27", N_("Traffic Jam")},
 {"28", N_("Sunshine")},
-{"29", N_("Block 10")},
-{"30", N_("Block 10 Pro")},
-{"31", N_("Climb 12")},
-{"32", N_("Climb 12 Pro")},
-{"33", N_("Climb 15 Winter")},
-{"34", N_("Climb 15 Spring")},
-{"35", N_("Climb 15 Summer")},
-{"36", N_("Climb 15 Fall")},
-{"37", N_("Climb 24 Pro")},
 GAMES_SCORES_LAST_CATEGORY
 };
 
@@ -160,10 +153,10 @@ void set_piece_id (char *, gint, gint, gint);
 gint move_piece (gint, gint, gint, gint, gint);
 void copymap (char *, char *);
 gint mapcmp (char *, char *);
-#ifdef HAVE_GNOME
-gint save_state (GnomeClient *, gint, GnomeRestartStyle, gint,
-		 GnomeInteractStyle, gint fast, gpointer);
-#endif /* HAVE_GNOME */              
+#ifdef WITH_SMCLIENT
+static int save_state_cb (EggSMClient *client, GKeyFile *keyfile, gpointer client_data);
+static int quit_cb (EggSMClient *client, gpointer client_data);
+#endif /* WITH_SMCLIENT */     
 void new_move (void);
 void game_score (void);
 gint game_over (void);
@@ -409,64 +402,6 @@ const levelinfo level[] = {
    "#ddFee** **ffOZZ#"
    "#MMKQQ*   *PPS^^#"
    "#VVLXX** **bbRcc#" "#VVLXXD***EbbRcc#" "#################"},
-
-  /* puzzle name */
-  {N_("Block 10"), 3,
-   6, 7, 30,
-   "##..##" "#a..c#" "#abcc#" "#ddfg#" "#d**g#" "#e**h#" "######"},
-
-  /* puzzle name */
-  {N_("Block 10 Pro"), 3,
-   6, 7, 81,
-   "##..##" "#a..b#" "#ccdd#" "#ecdf#" "#e**f#" "#g**h#" "######"},
-
-  /* puzzle name */
-  {N_("Climb 12"), 3,
-   7, 7, 59,
-   "###.###" "#a...b#" "#accdb#" "#ecddf#" "#gg*hh#" "#i***j#" "#######"},
-
-  /* puzzle name */
-  {N_("Climb 12 Pro"), 3,
-   7, 7, 92,
-   "###.###" "#a...b#" "#acddb#" "#effgh#" "#ee*hh#" "#i***j#" "#######"},
-
-  /* puzzle name */
-  {N_("Climb 15 Winter"), 3,
-   7, 9, 101,
-   "###.###"
-   "#a...b#"
-   "#cdefg#" "#ccegg#" "#hhijj#" "#hhikk#" "#ll*mm#" "#l***m#" "#######"},
-
-  /* puzzle name */
-  {N_("Climb 15 Spring"), 3,
-   7, 9, 104,
-   "###.###"
-   "#a...b#"
-   "#fedcc#" "#feddc#" "#hhigg#" "#hiigg#" "#ll*mm#" "#j***k#" "#######"},
-
-  /* puzzle name */
-  {N_("Climb 15 Summer"), 3,
-   7, 9, 132,
-   "###.###"
-   "#a...b#"
-   "#cceff#" "#ddeff#" "#gghii#" "#kghij#" "#kk*jj#" "#l***m#" "#######"},
-
-  /* puzzle name */
-  {N_("Climb 15 Fall"), 3,
-   7, 9, 148,
-   "###.###"
-   "#a...b#"
-   "#cceff#" "#ddegg#" "#dijjg#" "#hijjk#" "#hh*kk#" "#l***m#" "#######"},
-
-  /* puzzle name */
-  {N_("Climb 24 Pro"), 3,
-   9, 11, 227,
-   "####.####"
-   "#aa...bb#"
-   "#ccdddee#"
-   "#ccfggee#"
-   "#hhffgnn#"
-   "#ihklmno#" "#ijkzmpo#" "#jjqqqpp#" "#rrs*tuu#" "#rr***uu#" "#########"},
 };
 
 const gint max_level = G_N_ELEMENTS (level) - 1;
@@ -479,7 +414,6 @@ const char *pack_uipath[] = {
   "/ui/MainMenu/GameMenu/HuaRongTrail",
   "/ui/MainMenu/GameMenu/ChallengePack",
   "/ui/MainMenu/GameMenu/SkillPack",
-  "/ui/MainMenu/GameMenu/MinoruClimb"
 };
 
 const GtkActionEntry entries[] = {
@@ -492,8 +426,6 @@ const GtkActionEntry entries[] = {
   {"ChallengePack", NULL, N_("Challenge Pack")},
   /* set of puzzles */
   {"SkillPack", NULL, N_("Skill Pack")},
-  /* set of puzzles */
-  {"MinoruClimb", NULL, N_("Minoru Climb")},
   {"RestartPuzzle", GTK_STOCK_REFRESH, N_("_Restart Puzzle"), "<control>R",
    NULL, G_CALLBACK (restart_level_cb)},
   {"NextPuzzle", GTK_STOCK_GO_FORWARD, N_("Next Puzzle"), "Page_Down", NULL,
@@ -521,7 +453,6 @@ const char ui_description[] =
   "      <menu action='HuaRongTrail'/>"
   "      <menu action='ChallengePack'/>"
   "      <menu action='SkillPack'/>"
-  "      <menu action='MinoruClimb'/>"
   "      <separator/>"
   "      <menuitem action='Scores'/>"
   "      <separator/>"
@@ -554,13 +485,11 @@ main (int argc, char **argv)
   GtkWidget *vbox;
   GtkWidget *menubar;
   gint startup_level;
-#ifdef HAVE_GNOME
-  GnomeClient *client;
-  GnomeProgram *program;
-#else
   gboolean retval;
   GError *error = NULL;
-#endif
+#ifdef WITH_SMCLIENT
+  EggSMClient *sm_client;
+#endif /* WITH_SMCLIENT */
 
 #if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS)
   /* If we're going to use gnome-vfs, we need to init threads before
@@ -569,9 +498,12 @@ main (int argc, char **argv)
   g_thread_init (NULL);
 #endif
 
+  if (!games_runtime_init ("gnotski"))
+    return 1;
+
   setgid_io_init ();
 
-  bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+  bindtextdomain (GETTEXT_PACKAGE, games_runtime_get_directory (GAMES_RUNTIME_LOCALE_DIRECTORY));
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
@@ -579,25 +511,11 @@ main (int argc, char **argv)
 #if GLIB_CHECK_VERSION (2, 12, 0)
   g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
 #endif
-
-  g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
-
-#ifdef HAVE_GNOME
-  program = gnome_program_init (APPNAME, VERSION,
-				LIBGNOMEUI_MODULE,
-				argc, argv,
-				GNOME_PARAM_GOPTION_CONTEXT, context,
-				GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
-
-  client = gnome_master_client ();
-
-  g_signal_connect (client, "save_yourself",
-                    G_CALLBACK (save_state), argv[0]);
-  g_signal_connect (client, "die",
-                    G_CALLBACK (quit_game_cb), argv[0]);
-
-#else
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
+#ifdef WITH_SMCLIENT
+  g_option_context_add_group (context, egg_sm_client_get_option_group ());
+#endif /* WITH_SMCLIENT */
+  g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 
   retval = g_option_context_parse (context, &argc, &argv, &error);
   g_option_context_free (context);
@@ -606,7 +524,6 @@ main (int argc, char **argv)
     g_error_free (error);
     exit (1);
   }
-#endif /* HAVE_GNOME */
 
   g_set_application_name (_(APPNAME_LONG));
 
@@ -616,6 +533,14 @@ main (int argc, char **argv)
 
   gtk_window_set_default_icon_name ("gnome-klotski");
   
+#ifdef WITH_SMCLIENT
+  sm_client = egg_sm_client_get ();
+  g_signal_connect (sm_client, "save-state",
+		    G_CALLBACK (save_state_cb), NULL);
+  g_signal_connect (sm_client, "quit",
+                    G_CALLBACK (quit_cb), NULL);
+#endif /* WITH_SMCLIENT */
+
   highscores = games_scores_new (&scoredesc);
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -657,9 +582,7 @@ main (int argc, char **argv)
 
   games_conf_shutdown ();
 
-#ifdef HAVE_GNOME
-  g_object_unref (program);
-#endif /* HAVE_GNOME */
+  games_runtime_shutdown ();
 
   return 0;
 }
@@ -1246,10 +1169,12 @@ load_solved_state (void)
 void
 load_image (void)
 {
+  const char *dname;
   char *path;
   GError *error = NULL;
 
-  path = g_build_filename (PIXMAPDIR, "gnotski.svg", NULL);
+  dname = games_runtime_get_directory (GAMES_RUNTIME_GAME_PIXMAP_DIRECTORY);
+  path = g_build_filename (dname, "gnotski.svg", NULL);
   tiles_preimage = games_preimage_new_from_file (path, &error);
   g_free (path);
 
@@ -1546,36 +1471,43 @@ quit_game_cb (GtkAction * action)
   gtk_main_quit ();
 }
 
-#ifdef HAVE_GNOME
-
-gint
-save_state (GnomeClient * client, gint phase,
-	    GnomeRestartStyle save_style, gint shutdown,
-	    GnomeInteractStyle interact_style, gint fast,
+#ifdef WITH_SMCLIENT
+static int
+save_state_cb (EggSMClient *client,
+	    GKeyFile* keyfile,
 	    gpointer client_data)
 {
   gchar *argv[20];
-  gint i;
+  gint argc;
   gint xpos, ypos;
 
   gdk_window_get_origin (window->window, &xpos, &ypos);
 
-  i = 0;
-  argv[i++] = (gchar *) client_data;
-  argv[i++] = "-x";
-  argv[i++] = g_strdup_printf ("%d", xpos);
-  argv[i++] = "-y";
-  argv[i++] = g_strdup_printf ("%d", ypos);
+  argc = 0;
+  argv[argc++] = g_get_prgname ();
+  argv[argc++] = "-x";
+  argv[argc++] = g_strdup_printf ("%d", xpos);
+  argv[argc++] = "-y";
+  argv[argc++] = g_strdup_printf ("%d", ypos);
 
-  gnome_client_set_restart_command (client, i, argv);
-  gnome_client_set_clone_command (client, 0, NULL);
+  egg_sm_client_set_restart_command (client, argc, (const char **) argv);
 
   g_free (argv[2]);
   g_free (argv[4]);
+
   return TRUE;
 }
 
-#endif /* HAVE_GNOME */
+static gint
+quit_cb (EggSMClient *client,
+         gpointer client_data)
+{
+  gtk_main_quit ();
+
+  return FALSE;
+}
+
+#endif /* WITH_SMCLIENT */
 
 void
 level_cb (GtkAction * action, GtkRadioAction * current)
@@ -1606,11 +1538,7 @@ prev_level_cb (GtkAction * action)
 void
 help_cb (GtkAction * action)
 {
-#ifdef HAVE_GNOME
-  gnome_help_display ("gnotski.xml", NULL, NULL);
-#else
-#warning need to port help to gtk-only!
-#endif /* HAVE_GNOME */
+  games_help_display (window, "gnotski", NULL);
 }
 
 void
