@@ -23,14 +23,19 @@
 #include <string.h>
 #include <glib.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gtk/gtk.h>
 
-#include "games-card-common.h"
 #include "games-find-file.h"
 #include "games-files.h"
 #include "games-preimage.h"
+#include "games-runtime.h"
 
 #include "games-card-theme.h"
 
+struct _GamesCardThemeClass {
+  GObjectClass parent_class;
+};
+
 struct _GamesCardTheme {
   GObject parent;
 
@@ -62,39 +67,9 @@ struct _GamesCardTheme {
   guint subrender : 1;
   guint prescaled : 1;
 
-  guint antialias_set : 1;
-  guint antialias : 2; /* enough bits for cairo_antialias_t */
-  guint subpixel_order : 3; /* enough bits for cairo_subpixel_order_t */
-};
-
-static const char extra_cards[][12] = {
-  "black_joker",
-  "red_joker",
-  "back",
-  "slot"
-};
-
-static const char suites[][8] = {
-  "club",
-  "diamond",
-  "heart",
-  "spade"
-};
-
-static const char ranks[][6] = {
-  "1",
-  "2",
-  "3",
-  "4",
-  "5",
-  "6",
-  "7",
-  "8",
-  "9",
-  "10",
-  "jack",
-  "queen",
-  "king"
+#if GTK_CHECK_VERSION (2, 10, 0)
+  cairo_font_options_t *font_options;
+#endif
 };
 
 enum {
@@ -103,8 +78,12 @@ enum {
   PROP_THEME_DIRECTORY
 };
 
-/* FIXMEchpe: use uninstalled data dir for rendering the card theme! */
-#define SLOTDIR  PKGDATADIR "/pixmaps"
+enum {
+  CHANGED,
+  LAST_SIGNAL
+};
+
+static guint signals[LAST_SIGNAL];
 
 #define N_ROWS ((double) 5.0)
 #define N_COLS ((double) 13.0)
@@ -119,21 +98,6 @@ enum {
 static long totaltime = 0;
 #endif
 
-static inline void
-print_card_name (int card_id, char *buffer, gsize _size)
-{
-  int suit, rank;
-
-  suit = card_id / 13;
-  rank = card_id % 13;
-
-  if (G_LIKELY (suit < 4)) {
-    g_snprintf (buffer, _size, "%s-%s", suites[suit], ranks[rank]);
-  } else {
-    g_snprintf (buffer, _size, "%s", extra_cards[rank]);
-  }
-}
-
 static void
 games_card_theme_clear_source_pixbuf (GamesCardTheme * theme)
 {
@@ -192,7 +156,7 @@ games_card_theme_load_theme_scalable (GamesCardTheme * theme,
                                       const gchar * theme_name)
 {
   GamesPreimage *preimage;
-  const char *theme_dir, *env;
+  const char *theme_dir, *slot_dir, *env;
   gchar *filename, *path;
 
 #ifdef INSTRUMENT_LOADING
@@ -204,12 +168,13 @@ games_card_theme_load_theme_scalable (GamesCardTheme * theme,
   if (theme->theme_data.scalable.cards_preimage != NULL)
     return TRUE;
 
-  theme_dir =
-    theme->theme_dir != NULL ? theme->theme_dir : SCALABLE_CARDS_DIR;
+  theme_dir = theme->theme_dir;
+  if (!theme_dir)
+    return FALSE;
 
   /* First try and load the given file. */
   filename = g_strdup_printf ("%s.svg", theme_name);
-  path = games_build_filename (theme_dir, filename);
+  path = g_build_filename (theme_dir, filename, NULL);
   preimage = games_preimage_new_from_file (path, NULL);
   g_free (path);
 
@@ -227,10 +192,11 @@ games_card_theme_load_theme_scalable (GamesCardTheme * theme,
   if (!preimage)
     goto out;
 
-  if (theme->antialias_set) {
-    games_preimage_set_antialias (preimage, theme->antialias,
-                                  theme->subpixel_order);
+#if GTK_CHECK_VERSION (2, 10, 0)
+  if (theme->font_options) {
+    games_preimage_set_font_options (preimage, theme->font_options);
   }
+#endif
 
   theme->theme_data.scalable.cards_preimage = preimage;
   theme->prescaled = games_preimage_is_scalable (preimage);
@@ -243,14 +209,19 @@ games_card_theme_load_theme_scalable (GamesCardTheme * theme,
   }
 
   /* And the slot image */
-  path = games_build_filename (SLOTDIR, "slot.svg");
+  /* FIXMEchpe: use uninstalled data dir for rendering the card theme! */
+  slot_dir = games_runtime_get_directory (GAMES_RUNTIME_PIXMAP_DIRECTORY);
+  path = g_build_filename (slot_dir, "slot.svg", NULL);
   theme->theme_data.scalable.slot_preimage = games_preimage_new_from_file (path, NULL);
   g_free (path);
   g_return_val_if_fail (theme->theme_data.scalable.slot_preimage != NULL, FALSE);
 
-  if (theme->antialias_set)
-    games_preimage_set_antialias (theme->theme_data.scalable.slot_preimage,
-                                  theme->antialias, theme->subpixel_order);
+#if GTK_CHECK_VERSION (2, 10, 0)
+  if (theme->font_options) {
+    games_preimage_set_font_options (theme->theme_data.scalable.slot_preimage,
+                                     theme->font_options);
+  }
+#endif
 
   /* Use subrendering by default, but allow to override with the env var */
   theme->subrender = TRUE;
@@ -290,14 +261,16 @@ games_card_theme_load_theme_prerendered (GamesCardTheme * theme,
                                          const gchar * theme_name)
 {
   GKeyFile *key_file;
+  const char *theme_dir;
   char *filename, *path;
   GError *error = NULL;
   int *sizes = NULL;
   gsize n_sizes, i;
   gboolean retval = FALSE;
 
+  theme_dir = games_runtime_get_directory (GAMES_RUNTIME_PRERENDERED_CARDS_DIRECTORY);
   filename = g_strdup_printf ("%s.card-theme", theme_name);
-  path = games_build_filename (PRERENDERED_CARDS_DIR, filename);
+  path = g_build_filename (theme_dir, filename, NULL);
   g_free (filename);
 
   key_file = g_key_file_new ();
@@ -488,11 +461,7 @@ games_card_theme_render_card (GamesCardTheme * theme, int card_id)
     zoomx = width / card_width;
     zoomy = height / card_height;
 
-    if (G_LIKELY (suit < 4)) {
-      g_snprintf (node, sizeof (node), "#%s_%s", ranks[rank], suites[suit]);
-    } else {
-      g_snprintf (node, sizeof (node), "#%s", extra_cards[rank]);
-    }
+    games_card_get_node_by_suit_and_rank_snprintf (node, sizeof (node), suit, rank);
 
     subpixbuf = games_preimage_render_sub (preimage,
                                            node,
@@ -543,9 +512,9 @@ games_card_theme_load_card (GamesCardTheme * theme, int card_id)
 
   g_return_val_if_fail (!theme->use_scalable, NULL);
 
-  print_card_name (card_id, name, sizeof (name));
+  games_card_get_name_by_id_snprintf (name, sizeof (name), card_id);
   g_snprintf (filename, sizeof (filename), "%s.png", name);
-  path = games_build_filename (theme->theme_data.prerendered.themesizepath, filename);
+  path = g_build_filename (theme->theme_data.prerendered.themesizepath, filename, NULL);
 
   pixbuf = gdk_pixbuf_new_from_file (path, &error);
   if (!pixbuf) {
@@ -575,6 +544,12 @@ games_card_theme_finalize (GObject * object)
   g_free (theme->theme_name);
   g_free (theme->theme_dir);
 
+#if GTK_CHECK_VERSION (2, 10, 0)
+  if (theme->font_options) {
+    cairo_font_options_destroy (theme->font_options);
+  }
+#endif
+
   G_OBJECT_CLASS (games_card_theme_parent_class)->finalize (object);
 }
 
@@ -602,23 +577,54 @@ games_card_theme_set_property (GObject * object,
   GamesCardTheme *theme = GAMES_CARD_THEME (object);
 
   switch (prop_id) {
-  case PROP_SCALABLE:
-    theme->use_scalable = g_value_get_boolean (value) != FALSE;
+  case PROP_SCALABLE: {
+    gboolean use_scalable = (g_value_get_boolean (value) != FALSE);
+
+#ifndef HAVE_RSVG
+    if (use_scalable) {
+      g_warning ("Cannot enable scalable cards since RSVG support is not compiled in\n");
+      use_scalable = FALSE;
+    }
+#endif
+    theme->use_scalable = use_scalable; 
     break;
+  }
   case PROP_THEME_DIRECTORY:
     theme->theme_dir = g_value_dup_string (value);
+    if (!theme->theme_dir)
+      theme->theme_dir = g_strdup (games_runtime_get_directory (theme->use_scalable ? GAMES_RUNTIME_SCALABLE_CARDS_DIRECTORY
+                                                                                    : GAMES_RUNTIME_PRERENDERED_CARDS_DIRECTORY));
+
     break;
   }
 }
 
 static void
-games_card_theme_class_init (GamesCardThemeClass * class)
+games_card_theme_class_init (GamesCardThemeClass * klass)
 {
-  GObjectClass *gobject_class = G_OBJECT_CLASS (class);
+  GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
   gobject_class->set_property = games_card_theme_set_property;
   gobject_class->finalize = games_card_theme_finalize;
 
+  /**
+   * GamesCardTheme:changed:
+   * @theme: the object on which the signal is emitted
+   *
+   * The ::changed signal is emitted when the card theme has
+   * changed in any way that makes it necessary to re-render
+   * any displayed or cached images.
+   */
+  signals[CHANGED] =
+    g_signal_newv ("changed",
+                   G_TYPE_FROM_CLASS (klass),
+                   (GSignalFlags) (G_SIGNAL_RUN_LAST),
+                   NULL,
+                   NULL, NULL,
+                   g_cclosure_marshal_VOID__VOID,
+                   G_TYPE_NONE,
+                   0, NULL);
+
   g_object_class_install_property
     (gobject_class,
      PROP_SCALABLE,
@@ -627,7 +633,8 @@ games_card_theme_class_init (GamesCardThemeClass * class)
                            G_PARAM_WRITABLE |
                            G_PARAM_STATIC_NAME |
                            G_PARAM_STATIC_NICK |
-                           G_PARAM_STATIC_BLURB | G_PARAM_CONSTRUCT_ONLY));
+                           G_PARAM_STATIC_BLURB |
+                           G_PARAM_CONSTRUCT_ONLY));
   g_object_class_install_property
     (gobject_class,
      PROP_THEME_DIRECTORY,
@@ -636,7 +643,8 @@ games_card_theme_class_init (GamesCardThemeClass * class)
                           G_PARAM_WRITABLE |
                           G_PARAM_STATIC_NAME |
                           G_PARAM_STATIC_NICK |
-                          G_PARAM_STATIC_BLURB | G_PARAM_CONSTRUCT_ONLY));
+                          G_PARAM_STATIC_BLURB |
+                          G_PARAM_CONSTRUCT_ONLY));
 }
 
 /* public API */
@@ -653,38 +661,47 @@ GamesCardTheme *
 games_card_theme_new (const char *theme_dir, gboolean scalable)
 {
   return g_object_new (GAMES_TYPE_CARD_THEME,
-                       "theme-directory", theme_dir,
                        "scalable", scalable,
+                       "theme-directory", theme_dir,
                        NULL);
 }
 
+#if GTK_CHECK_VERSION (2, 10, 0)
+
 /**
- * games_card_theme_set_antialias:
+ * games_card_theme_set_font_options:
  * @theme:
- * @antialias: the antialiasing mode to use (see @cairo_antialias_t)
- * @subpixel_order: the subpixel order to use (see @cairo_subpixel_order_t)
- * if @antialias is %CAIRO_ANTIALIAS_SUBPIXEL 
+ * @font_options: the #cairo_font_options_t to use
  *
- * Turns on antialising of cards, if using a scalable theme.
+ * Sets the font options to use when drawing the card images.
  */
 void
-games_card_theme_set_antialias (GamesCardTheme * theme,
-                                guint antialias, guint subpixel_order)
+games_card_theme_set_font_options (GamesCardTheme * theme,
+                                   const cairo_font_options_t *font_options)
 {
   g_return_if_fail (GAMES_IS_CARD_THEME (theme));
 
-  if (theme->antialias_set &&
-      theme->antialias == antialias &&
-      theme->subpixel_order == subpixel_order)
+  if (font_options &&
+      theme->font_options &&
+      cairo_font_options_equal (font_options, theme->font_options))
     return;
 
-  theme->antialias_set = TRUE;
-  theme->antialias = antialias;
-  theme->subpixel_order = subpixel_order;
+  if (theme->font_options) {
+    cairo_font_options_destroy (theme->font_options);
+  }
+
+  if (font_options) {
+    theme->font_options = cairo_font_options_copy (font_options);
+  } else {
+    theme->font_options = NULL;
+  }
 
   games_card_theme_clear_source_pixbuf (theme);
+  g_signal_emit (theme, signals[CHANGED], 0);
 }
 
+#endif /* GTK 2.10.0 */
+
 /**
  * games_card_theme_set_theme:
  * @theme:
@@ -710,6 +727,7 @@ games_card_theme_set_theme (GamesCardTheme * theme, const gchar * theme_name)
 
   games_card_theme_clear_source_pixbuf (theme);
   games_card_theme_clear_theme_data (theme);
+  g_signal_emit (theme, signals[CHANGED], 0);
 
   theme->card_size.width = theme->card_size.height = theme->slot_size.width =
     theme->slot_size.width = -1;
@@ -756,8 +774,8 @@ games_card_theme_set_size (GamesCardTheme * theme,
     return FALSE;
   }
 
-  if ((width == theme->slot_size.width)
-      && (height == theme->slot_size.height))
+  if ((width == theme->slot_size.width) &&
+      (height == theme->slot_size.height))
     return FALSE;
 
   theme->slot_size.width = width;
@@ -792,9 +810,7 @@ games_card_theme_set_size (GamesCardTheme * theme,
   {
     guint i;
     int twidth, theight;
-    gchar *spath;
-    CardSize size = { -1, -1 }, fit_size = {
-    -1, -1};
+    CardSize size = { -1, -1 }, fit_size = { -1, -1};
 
     twidth = FLOAT_TO_INT_CEIL (((double) width) * proportion);
     theight = FLOAT_TO_INT_CEIL (((double) height) * proportion);
@@ -819,7 +835,7 @@ games_card_theme_set_size (GamesCardTheme * theme,
       size = fit_size;
 
     if (size.width > 0 && size.height > 0) {
-      char sizestr[32];
+      char sizestr[16];
 
       if (size.width == theme->card_size.width &&
           size.height == theme->card_size.height)
@@ -828,13 +844,8 @@ games_card_theme_set_size (GamesCardTheme * theme,
       g_free (theme->theme_data.prerendered.themesizepath);
 
       g_snprintf (sizestr, sizeof (sizestr), "%d", size.width);
-      spath = g_build_filename (theme->theme_dir !=
-                          NULL ? theme->theme_dir : PRERENDERED_CARDS_DIR,
-                          theme->theme_name, NULL);
-      
-      theme->theme_data.prerendered.themesizepath = 
-	      				games_build_filename (spath, sizestr);
-      g_free (spath);
+      theme->theme_data.prerendered.themesizepath =
+        g_build_filename (theme->theme_dir, theme->theme_name, sizestr, NULL);
 
       theme->size_available = TRUE;
       theme->card_size = size;
@@ -851,6 +862,7 @@ games_card_theme_set_size (GamesCardTheme * theme,
   }
 
   games_card_theme_clear_source_pixbuf (theme);
+  g_signal_emit (theme, signals[CHANGED], 0);
 
   return TRUE;
 }
@@ -940,22 +952,3 @@ games_card_theme_get_card_pixbuf (GamesCardTheme * theme, gint card_id)
 
   return pixbuf;
 }
-
-/**
- * games_card_theme_get_card_name:
- * @theme:
- * @cardid:
- *
- * Returns the name of the card @cardid
- *
- * Returns: a newly allocated string containing the card's name
- */
-char *
-games_card_theme_get_card_name (GamesCardTheme * theme, gint card_id)
-{
-  char name[128];
-
-  print_card_name (card_id, name, sizeof (name));
-
-  return g_strdup (name);
-}
