@@ -6,10 +6,16 @@
  *
  */
 
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
+#include <config.h>
+
 #include <string.h>
 
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+
+#include <libgames-support/games-conf.h>
+#include <libgames-support/games-runtime.h>
+
 #include "same-gnome.h"
 
 #include "drawing.h"
@@ -127,7 +133,7 @@ fast_animation_enable (gboolean state)
 {
   fast_animation = state;
 
-  gconf_client_set_bool (gcclient, GCONF_FAST_ANIMATION_KEY, state, NULL);
+  games_conf_set_boolean (NULL, KEY_FAST_ANIMATION, state);
 }
 
 void
@@ -314,7 +320,7 @@ render_cb (GtkWidget * canvas)
     if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
       g_free (filename);
       /* Then look in the system directory. */
-      filename = g_build_filename (THEMEDIR, theme, NULL);
+      filename = g_build_filename (games_runtime_get_directory (GAMES_RUNTIME_GAME_THEME_DIRECTORY), THEME_VERSION, theme, NULL);
       if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
 	/* Some old themes had a -sync just before the suffix. This was
 	 * hidden from the user and has been eliminated from the names
@@ -334,7 +340,7 @@ render_cb (GtkWidget * canvas)
 	  if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
 	    /* And finally fall back to the default. */
 	    g_free (filename);
-	    filename = g_build_filename (THEMEDIR, DEFAULT_THEME, NULL);
+            filename = g_build_filename (games_runtime_get_directory (GAMES_RUNTIME_GAME_THEME_DIRECTORY), THEME_VERSION, DEFAULT_THEME, NULL);
 	  }
 	}
       }
@@ -593,7 +599,7 @@ change_theme (gchar * newtheme)
     start_renderer ();
     redraw ();
 
-    gconf_client_set_string (gcclient, GCONF_THEME_KEY, theme, NULL);
+    games_conf_set_string (NULL, KEY_THEME, theme);
   }
 }
 
