@@ -11,15 +11,13 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
-#ifdef HAVE_GNOME
-#include <libgnome/gnome-help.h>
-#endif /* HAVE_GNOME */
-
 #include <libgames-support/games-conf.h>
 #include <libgames-support/games-files.h>
 #include <libgames-support/games-gridframe.h>
+#include <libgames-support/games-help.h>
 #include <libgames-support/games-scores-dialog.h>
 #include <libgames-support/games-stock.h>
+#include <libgames-support/games-runtime.h>
 
 #include "same-gnome.h"
 
@@ -282,6 +280,7 @@ theme_cb (void)
   GtkTreeSelection *selection;
   GtkListStore *list;
   GamesFileList *filelist;
+  char *themedir;
 
   if (dialog) {
     gtk_window_present (GTK_WINDOW (dialog));
@@ -316,10 +315,12 @@ theme_cb (void)
 
     current_theme_index = -1;
     theme_index_counter = 0;
-    filelist = games_file_list_new_images (THEMEDIR, localthemedir, NULL);
+    themedir = g_build_filename (games_runtime_get_directory (GAMES_RUNTIME_GAME_THEME_DIRECTORY), THEME_VERSION, NULL);
+    filelist = games_file_list_new_images (themedir, localthemedir, NULL);
     games_file_list_transform_basename (filelist);
     games_file_list_for_each (filelist, (GFunc) fill_list, list);
     g_object_unref (filelist);
+    g_free (themedir);
 
     listview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (list));
     g_object_unref (list);
@@ -443,11 +444,7 @@ size_change_cb (GtkRadioAction * action, gpointer data)
 static void
 help_cb (void)
 {
-#ifdef HAVE_GNOME
-  gnome_help_display ("same-gnome.xml", NULL, NULL);
-#else
-#warning need to port help to gtk-only!
-#endif /* HAVE_GNOME */
+  games_help_display (application, "same-gnome", NULL);
 }
 
 /* FIXME: Will we ever want this ? */
